@@ -3,7 +3,7 @@
 
 import { afterAll, afterEach, beforeAll, expect, vi } from 'vitest';
 import { cleanup } from '@testing-library/react';
-import * as matchers from '@testing-library/jest-dom/matchers';
+import * as matchers from '@testing-library/jest-dom/vitest';
 import { server } from './mocks/node';
 
 expect.extend(matchers);
