@@ -1,14 +1,14 @@
 import { Typography } from '@material-tailwind/react';
 
-import TicketRow from '@/components/ui/JobsPage/TicketRow';
 import { useTicketContext } from '@/contexts/TicketsContext';
-import { TableCard } from './ui/widgets/TableCard';
+import { TableCard } from './ui/Table/TableCard';
+import { jobsColumns } from './ui/Table/jobsColumns';
 
 export default function Jobs() {
   const { allTickets, loadingTickets } = useTicketContext();
   return (
     <>
-      <Typography type="h5" className="mb-6 text-foreground font-bold">
+      <Typography className="mb-6 text-foreground font-bold" type="h5">
         Tasks
       </Typography>
       <Typography className="mb-6 text-foreground">
@@ -18,12 +18,11 @@ export default function Jobs() {
         <strong>Convert</strong> button.
       </Typography>
       <TableCard
-        gridColsClass="grid-cols-[2fr_3fr_1fr_1fr]"
-        rowTitles={['File Path', 'Job Description', 'Status', 'Last Updated']}
-        rowContent={TicketRow}
-        items={allTickets}
-        loadingState={loadingTickets}
+        columns={jobsColumns}
+        data={allTickets || []}
         emptyText="You have not made any conversion requests."
+        gridColsClass="grid-cols-[2fr_3fr_1fr_1fr]"
+        loadingState={loadingTickets}
       />
     </>
   );
