@@ -6,12 +6,12 @@ import NavigationInput from '@/components/ui/BrowsePage/NavigateInput';
 import FgDialog from '@/components/ui/Dialogs/FgDialog';
 
 type NavigationButtonProps = {
-  triggerClasses: string;
+  readonly triggerClasses: string;
 };
 
 export default function NavigationButton({
   triggerClasses
-}: NavigationButtonProps): JSX.Element {
+}: NavigationButtonProps): React.JSX.Element {
   const [showNavigationDialog, setShowNavigationDialog] = React.useState(false);
 
   return (
@@ -25,17 +25,17 @@ export default function NavigationButton({
         }}
         triggerClasses={triggerClasses}
       />
-      {showNavigationDialog && (
+      {showNavigationDialog ? (
         <FgDialog
-          open={showNavigationDialog}
           onClose={() => setShowNavigationDialog(false)}
+          open={showNavigationDialog}
         >
           <NavigationInput
             location="dialog"
             setShowNavigationDialog={setShowNavigationDialog}
           />
         </FgDialog>
-      )}
+      ) : null}
     </>
   );
 }
