@@ -3,11 +3,16 @@ import { default as log } from '@/logger';
 
 import type { FileSharePath, Zone } from '@/shared.types';
 import { useCookiesContext } from '@/contexts/CookiesContext';
-import { useZoneAndFspMapContext } from './ZonesAndFspMapContext';
-import { useFileBrowserContext } from './FileBrowserContext';
+import { useZoneAndFspMapContext } from '@/contexts/ZonesAndFspMapContext';
+import { useFileBrowserContext } from '@/contexts/FileBrowserContext';
 import { sendFetchRequest, makeMapKey, HTTPError } from '@/utils';
 import { createSuccess, handleError, toHttpError } from '@/utils/errorHandling';
 import type { Result } from '@/shared.types';
+import {
+  LAYOUT_NAME,
+  WITH_PROPERTIES_AND_SIDEBAR,
+  ONLY_PROPERTIES
+} from '@/constants/layoutConstants';
 
 export type FolderFavorite = {
   type: 'folder';
@@ -31,10 +36,14 @@ type PreferencesContextType = {
   ) => Promise<Result<void>>;
   hideDotFiles: boolean;
   toggleHideDotFiles: () => Promise<Result<void>>;
+  areDataLinksAutomatic: boolean;
+  toggleAutomaticDataLinks: () => Promise<Result<void>>;
   disableNeuroglancerStateGeneration: boolean;
   toggleDisableNeuroglancerStateGeneration: () => Promise<Result<void>>;
   disableHeuristicalLayerTypeDetection: boolean;
   toggleDisableHeuristicalLayerTypeDetection: () => Promise<Result<void>>;
+  useLegacyMultichannelApproach: boolean;
+  toggleUseLegacyMultichannelApproach: () => Promise<Result<void>>;
   zonePreferenceMap: Record<string, ZonePreference>;
   zoneFavorites: Zone[];
   fileSharePathPreferenceMap: Record<string, FileSharePathPreference>;
@@ -49,9 +58,12 @@ type PreferencesContextType = {
   recentlyViewedFolders: FolderPreference[];
   layout: string;
   handleUpdateLayout: (layout: string) => Promise<void>;
+  setLayoutWithPropertiesOpen: () => Promise<Result<void>>;
   loadingRecentlyViewedFolders: boolean;
   isLayoutLoadedFromDB: boolean;
   handleContextMenuFavorite: () => Promise<Result<boolean>>;
+  isFilteredByGroups: boolean;
+  toggleFilterByGroups: () => Promise<Result<void>>;
 };
 
 const PreferencesContext = React.createContext<PreferencesContextType | null>(
@@ -71,12 +83,14 @@ export const usePreferencesContext = () => {
 export const PreferencesProvider = ({
   children
 }: {
-  children: React.ReactNode;
+  readonly children: React.ReactNode;
 }) => {
   const [pathPreference, setPathPreference] = React.useState<
     ['linux_path'] | ['windows_path'] | ['mac_path']
   >(['linux_path']);
   const [hideDotFiles, setHideDotFiles] = React.useState<boolean>(false);
+  const [areDataLinksAutomatic, setAreDataLinksAutomatic] =
+    React.useState<boolean>(false);
   const [
     disableNeuroglancerStateGeneration,
     setDisableNeuroglancerStateGeneration
@@ -85,6 +99,8 @@ export const PreferencesProvider = ({
     disableHeuristicalLayerTypeDetection,
     setDisableHeuristicalLayerTypeDetection
   ] = React.useState<boolean>(false);
+  const [useLegacyMultichannelApproach, setUseLegacyMultichannelApproach] =
+    React.useState<boolean>(false);
   const [zonePreferenceMap, setZonePreferenceMap] = React.useState<
     Record<string, ZonePreference>
   >({});
@@ -110,37 +126,38 @@ export const PreferencesProvider = ({
   const [layout, setLayout] = React.useState<string>('');
   const [isLayoutLoadedFromDB, setIsLayoutLoadedFromDB] = React.useState(false);
 
+  // Default to true for filtering by groups
+  const [isFilteredByGroups, setIsFilteredByGroups] =
+    React.useState<boolean>(true);
+
   const { cookies } = useCookiesContext();
   const { isZonesMapReady, zonesAndFileSharePathsMap } =
     useZoneAndFspMapContext();
   const { fileBrowserState } = useFileBrowserContext();
 
-  const fetchPreferences = React.useCallback(
-    async (key: string) => {
-      try {
-        const data = await sendFetchRequest(
-          `/api/fileglancer/preference?key=${key}`,
-          'GET',
-          cookies['_xsrf']
-        ).then(response => response.json());
-        return data?.value;
-      } catch (error) {
-        if (error instanceof HTTPError && error.responseCode === 404) {
-          log.debug(`Preference '${key}' not found`);
-        } else {
-          log.error(`Error fetching preference '${key}':`, error);
-        }
-        return null;
+  const fetchPreferences = React.useCallback(async () => {
+    try {
+      const data = await sendFetchRequest(
+        `/api/preference`,
+        'GET',
+        cookies['_xsrf']
+      ).then(response => response.json());
+      return data;
+    } catch (error) {
+      if (error instanceof HTTPError && error.responseCode === 404) {
+        return {}; // No preferences found, return empty object
+      } else {
+        log.error(`Error fetching preferences:`, error);
       }
-    },
-    [cookies]
-  );
+      return {};
+    }
+  }, [cookies]);
 
   const accessMapItems = React.useCallback(
     (keys: string[]) => {
-      const itemsArray = keys.map(key => {
-        return zonesAndFileSharePathsMap[key];
-      });
+      const itemsArray = keys
+        .map(key => zonesAndFileSharePathsMap[key])
+        .filter(item => item !== undefined);
       return itemsArray;
     },
     [zonesAndFileSharePathsMap]
@@ -196,7 +213,7 @@ export const PreferencesProvider = ({
   const savePreferencesToBackend = React.useCallback(
     async <T,>(key: string, value: T): Promise<Response> => {
       const response = await sendFetchRequest(
-        `/api/fileglancer/preference?key=${key}`,
+        `/api/preference/${key}`,
         'PUT',
         cookies['_xsrf'],
         { value: value }
@@ -215,6 +232,34 @@ export const PreferencesProvider = ({
     setLayout(layout);
   };
 
+  const setLayoutWithPropertiesOpen = async (): Promise<Result<void>> => {
+    try {
+      // Keep sidebar in new layout if it is currently present
+      const hasSidebar = layout.includes('sidebar');
+
+      const layoutKey = hasSidebar
+        ? WITH_PROPERTIES_AND_SIDEBAR
+        : ONLY_PROPERTIES;
+
+      const layoutSizes = hasSidebar ? [24, 50, 26] : [75, 25];
+
+      const newLayout = {
+        [LAYOUT_NAME]: {
+          [layoutKey]: {
+            expandToSizes: {},
+            layout: layoutSizes
+          }
+        }
+      };
+      const newLayoutString = JSON.stringify(newLayout);
+      await savePreferencesToBackend('layout', newLayoutString);
+      setLayout(newLayoutString);
+      return createSuccess(undefined);
+    } catch (error) {
+      return handleError(error);
+    }
+  };
+
   const handlePathPreferenceSubmit = React.useCallback(
     async (
       localPathPreference: ['linux_path'] | ['windows_path'] | ['mac_path']
@@ -230,39 +275,50 @@ export const PreferencesProvider = ({
     [savePreferencesToBackend]
   );
 
-  const toggleHideDotFiles = React.useCallback(async (): Promise<
-    Result<void>
-  > => {
-    try {
-      setHideDotFiles(prevHideDotFiles => {
-        const newValue = !prevHideDotFiles;
-        savePreferencesToBackend('hideDotFiles', newValue);
-        return newValue;
-      });
-    } catch (error) {
-      return handleError(error);
-    }
-    return createSuccess(undefined);
-  }, [savePreferencesToBackend]);
-
-  const toggleDisableNeuroglancerStateGeneration =
-    React.useCallback(async (): Promise<Result<void>> => {
+  const togglePreference = React.useCallback(
+    async <T extends boolean>(
+      key: string,
+      setter: React.Dispatch<React.SetStateAction<T>>
+    ): Promise<Result<void>> => {
       try {
-        setDisableNeuroglancerStateGeneration(
-          prevDisableNeuroglancerStateGeneration => {
-            const newValue = !prevDisableNeuroglancerStateGeneration;
-            savePreferencesToBackend(
-              'disableNeuroglancerStateGeneration',
-              newValue
-            );
-            return newValue;
-          }
-        );
+        setter((prevValue: T) => {
+          const newValue = !prevValue as T;
+          savePreferencesToBackend(key, newValue);
+          return newValue;
+        });
       } catch (error) {
         return handleError(error);
       }
       return createSuccess(undefined);
-    }, [savePreferencesToBackend]);
+    },
+    [savePreferencesToBackend]
+  );
+
+  const toggleFilterByGroups = React.useCallback(async (): Promise<
+    Result<void>
+  > => {
+    return await togglePreference('isFilteredByGroups', setIsFilteredByGroups);
+  }, [togglePreference]);
+
+  const toggleHideDotFiles = React.useCallback(async (): Promise<
+    Result<void>
+  > => {
+    return togglePreference('hideDotFiles', setHideDotFiles);
+  }, [togglePreference]);
+
+  const toggleAutomaticDataLinks = React.useCallback(async (): Promise<
+    Result<void>
+  > => {
+    return togglePreference('areDataLinksAutomatic', setAreDataLinksAutomatic);
+  }, [togglePreference]);
+
+  const toggleDisableNeuroglancerStateGeneration =
+    React.useCallback(async (): Promise<Result<void>> => {
+      return togglePreference(
+        'disableNeuroglancerStateGeneration',
+        setDisableNeuroglancerStateGeneration
+      );
+    }, [togglePreference]);
 
   const toggleDisableHeuristicalLayerTypeDetection =
     React.useCallback(async (): Promise<Result<void>> => {
@@ -283,6 +339,14 @@ export const PreferencesProvider = ({
       return createSuccess(undefined);
     }, [savePreferencesToBackend]);
 
+  const toggleUseLegacyMultichannelApproach =
+    React.useCallback(async (): Promise<Result<void>> => {
+      return togglePreference(
+        'useLegacyMultichannelApproach',
+        setUseLegacyMultichannelApproach
+      );
+    }, [togglePreference]);
+
   function updatePreferenceList<T>(
     key: string,
     itemToUpdate: T,
@@ -432,173 +496,48 @@ export const PreferencesProvider = ({
     }
   };
 
-  const updateRecentlyViewedFolders = React.useCallback(
-    (folderPath: string, fspName: string): FolderPreference[] => {
-      const updatedFolders = [...recentlyViewedFolders];
-
-      // Do not save file share paths in the recently viewed folders
-      if (folderPath === '.') {
-        return updatedFolders;
-      }
-
-      const newItem = {
-        type: 'folder',
-        folderPath: folderPath,
-        fspName: fspName
-      } as FolderPreference;
-
-      // First, if length is 0, just add the new item
-      if (updatedFolders.length === 0) {
-        updatedFolders.push(newItem);
-        return updatedFolders;
-      }
-      // Check if folderPath is a descendant path of the most recently viewed folder path
-      // Or if it is a direct ancestor of the most recently viewed folder path
-      // If it is, replace the most recent item
-      if (
-        (updatedFolders.length > 0 &&
-          folderPath.startsWith(updatedFolders[0].folderPath)) ||
-        updatedFolders[0].folderPath.startsWith(folderPath)
-      ) {
-        updatedFolders[0] = newItem;
-        return updatedFolders;
-      } else {
-        const index = updatedFolders.findIndex(
-          folder =>
-            folder.folderPath === newItem.folderPath &&
-            folder.fspName === newItem.fspName
-        );
-        if (index === -1) {
-          updatedFolders.unshift(newItem);
-          if (updatedFolders.length > 10) {
-            updatedFolders.pop(); // Remove the oldest entry if we exceed the 10 item limit
-          }
-        } else if (index > 0) {
-          // If the folder is already in the list, move it to the front
-          updatedFolders.splice(index, 1);
-          updatedFolders.unshift(newItem);
-        }
-        return updatedFolders;
-      }
-    },
-    [recentlyViewedFolders]
-  );
-
-  React.useEffect(() => {
-    (async function () {
-      if (isLayoutLoadedFromDB) {
-        return; // Avoid re-fetching if already loaded
-      }
-      const rawLayoutPref = await fetchPreferences('layout');
-      if (rawLayoutPref) {
-        log.debug('setting layout:', rawLayoutPref);
-        setLayout(rawLayoutPref);
-      }
-      setIsLayoutLoadedFromDB(true);
-    })();
-  }, [fetchPreferences, isLayoutLoadedFromDB]);
-
-  React.useEffect(() => {
-    (async function () {
-      const rawPathPreference = await fetchPreferences('path');
-      if (rawPathPreference) {
-        log.debug('setting initial path preference:', rawPathPreference);
-        setPathPreference(rawPathPreference);
-      }
-    })();
-  }, [fetchPreferences]);
-
-  React.useEffect(() => {
-    (async function () {
-      const rawHideDotFiles = await fetchPreferences('hideDotFiles');
-      if (rawHideDotFiles !== null) {
-        log.debug('setting initial hideDotFiles preference:', rawHideDotFiles);
-        setHideDotFiles(rawHideDotFiles);
-      }
-    })();
-  }, [fetchPreferences]);
-
-  React.useEffect(() => {
-    (async function () {
-      const rawDisableNeuroglancerStateGeneration = await fetchPreferences(
-        'disableNeuroglancerStateGeneration'
-      );
-      if (rawDisableNeuroglancerStateGeneration !== null) {
-        log.debug(
-          'setting initial disableNeuroglancerStateGeneration preference:',
-          rawDisableNeuroglancerStateGeneration
-        );
-        setDisableNeuroglancerStateGeneration(
-          rawDisableNeuroglancerStateGeneration
-        );
-      }
-    })();
-  }, [fetchPreferences]);
-
-  React.useEffect(() => {
-    (async function () {
-      const rawDisableHeuristicalLayerTypeDetection = await fetchPreferences(
-        'disableHeuristicalLayerTypeDetection'
-      );
-      if (rawDisableHeuristicalLayerTypeDetection !== null) {
-        log.debug(
-          'setting initial disableHeuristicalLayerTypeDetection preference:',
-          rawDisableHeuristicalLayerTypeDetection
-        );
-        setDisableHeuristicalLayerTypeDetection(
-          rawDisableHeuristicalLayerTypeDetection
-        );
-      }
-    })();
-  }, [fetchPreferences]);
-
+  // Fetch all preferences on mount
   React.useEffect(() => {
     if (!isZonesMapReady) {
       return;
     }
+    if (isLayoutLoadedFromDB) {
+      return; // Avoid re-fetching if already loaded
+    }
+
+    setLoadingRecentlyViewedFolders(true);
 
     (async function () {
-      const backendPrefs = await fetchPreferences('zone');
+      const allPrefs = await fetchPreferences();
+
+      // Zone favorites
+      const zoneBackendPrefs = allPrefs.zone?.value;
       const zoneArray =
-        backendPrefs?.map((pref: ZonePreference) => {
+        zoneBackendPrefs?.map((pref: ZonePreference) => {
           const key = makeMapKey(pref.type, pref.name);
           return { [key]: pref };
         }) || [];
       const zoneMap = Object.assign({}, ...zoneArray);
-      if (zoneMap) {
+      if (Object.keys(zoneMap).length > 0) {
         updateLocalZonePreferenceStates(zoneMap);
       }
-    })();
-  }, [isZonesMapReady, fetchPreferences, updateLocalZonePreferenceStates]);
 
-  React.useEffect(() => {
-    if (!isZonesMapReady) {
-      return;
-    }
-
-    (async function () {
-      const backendPrefs = await fetchPreferences('fileSharePath');
+      // FileSharePath favorites
+      const fspBackendPrefs = allPrefs.fileSharePath?.value;
       const fspArray =
-        backendPrefs?.map((pref: FileSharePathPreference) => {
+        fspBackendPrefs?.map((pref: FileSharePathPreference) => {
           const key = makeMapKey(pref.type, pref.name);
           return { [key]: pref };
         }) || [];
       const fspMap = Object.assign({}, ...fspArray);
-      if (fspMap) {
+      if (Object.keys(fspMap).length > 0) {
         updateLocalFspPreferenceStates(fspMap);
       }
-    })();
-  }, [isZonesMapReady, fetchPreferences, updateLocalFspPreferenceStates]);
 
-  React.useEffect(() => {
-    if (!isZonesMapReady) {
-      return;
-    }
-
-    (async function () {
-      const backendPrefs = await fetchPreferences('folder');
+      // Folder favorites
+      const folderBackendPrefs = allPrefs.folder?.value;
       const folderArray =
-        backendPrefs?.map((pref: FolderPreference) => {
+        folderBackendPrefs?.map((pref: FolderPreference) => {
           const key = makeMapKey(
             pref.type,
             `${pref.fspName}_${pref.folderPath}`
@@ -606,33 +545,120 @@ export const PreferencesProvider = ({
           return { [key]: pref };
         }) || [];
       const folderMap = Object.assign({}, ...folderArray);
-      if (folderMap) {
+      if (Object.keys(folderMap).length > 0) {
         updateLocalFolderPreferenceStates(folderMap);
       }
-    })();
-  }, [isZonesMapReady, fetchPreferences, updateLocalFolderPreferenceStates]);
 
-  // Get initial recently viewed folders from backend
-  React.useEffect(() => {
-    setLoadingRecentlyViewedFolders(true);
-    if (!isZonesMapReady) {
-      return;
-    }
-    (async function () {
-      const backendPrefs = (await fetchPreferences(
-        'recentlyViewedFolders'
-      )) as FolderPreference[];
-      if (backendPrefs && backendPrefs.length > 0) {
-        setRecentlyViewedFolders(backendPrefs);
+      // Recently viewed folders
+      const recentlyViewedBackendPrefs = allPrefs.recentlyViewedFolders?.value;
+      if (recentlyViewedBackendPrefs && recentlyViewedBackendPrefs.length > 0) {
+        setRecentlyViewedFolders(recentlyViewedBackendPrefs);
+      }
+
+      // Layout preference
+      if (allPrefs.layout?.value) {
+        setLayout(allPrefs.layout.value);
+      }
+
+      // Path preference
+      if (allPrefs.path?.value) {
+        setPathPreference(allPrefs.path.value);
+      }
+
+      // Boolean preferences
+      if (allPrefs.isFilteredByGroups?.value !== undefined) {
+        setIsFilteredByGroups(allPrefs.isFilteredByGroups.value);
+      }
+      if (allPrefs.hideDotFiles?.value !== undefined) {
+        setHideDotFiles(allPrefs.hideDotFiles.value);
+      }
+      if (allPrefs.areDataLinksAutomatic?.value !== undefined) {
+        setAreDataLinksAutomatic(allPrefs.areDataLinksAutomatic.value);
+      }
+      if (allPrefs.disableNeuroglancerStateGeneration?.value !== undefined) {
+        setDisableNeuroglancerStateGeneration(
+          allPrefs.disableNeuroglancerStateGeneration.value
+        );
+      }
+      if (allPrefs.disableHeuristicalLayerTypeDetection?.value !== undefined) {
+        setDisableHeuristicalLayerTypeDetection(
+          allPrefs.disableHeuristicalLayerTypeDetection.value
+        );
+      }
+      if (allPrefs.useLegacyMultichannelApproach?.value !== undefined) {
+        setUseLegacyMultichannelApproach(
+          allPrefs.useLegacyMultichannelApproach.value
+        );
       }
       setLoadingRecentlyViewedFolders(false);
+      setIsLayoutLoadedFromDB(true);
     })();
-  }, [fetchPreferences, isZonesMapReady]);
+  }, [
+    fetchPreferences,
+    isZonesMapReady,
+    isLayoutLoadedFromDB,
+    updateLocalZonePreferenceStates,
+    updateLocalFspPreferenceStates,
+    updateLocalFolderPreferenceStates
+  ]);
 
   // Store last viewed folder path and FSP name to avoid duplicate updates
   const lastFolderPathRef = React.useRef<string | null>(null);
   const lastFspNameRef = React.useRef<string | null>(null);
 
+  const updateRecentlyViewedFolders = (
+    folderPath: string,
+    fspName: string,
+    currentRecentlyViewedFolders: FolderPreference[]
+  ): FolderPreference[] => {
+    const updatedFolders = [...currentRecentlyViewedFolders];
+
+    // Do not save file share paths in the recently viewed folders
+    if (folderPath === '.') {
+      return updatedFolders;
+    }
+
+    const newItem = {
+      type: 'folder',
+      folderPath: folderPath,
+      fspName: fspName
+    } as FolderPreference;
+
+    // First, if length is 0, just add the new item
+    if (updatedFolders.length === 0) {
+      updatedFolders.push(newItem);
+      return updatedFolders;
+    }
+    // Check if folderPath is a descendant path of the most recently viewed folder path
+    // Or if it is a direct ancestor of the most recently viewed folder path
+    // If it is, replace the most recent item
+    if (
+      (updatedFolders.length > 0 &&
+        folderPath.startsWith(updatedFolders[0].folderPath)) ||
+      updatedFolders[0].folderPath.startsWith(folderPath)
+    ) {
+      updatedFolders[0] = newItem;
+      return updatedFolders;
+    } else {
+      const index = updatedFolders.findIndex(
+        folder =>
+          folder.folderPath === newItem.folderPath &&
+          folder.fspName === newItem.fspName
+      );
+      if (index === -1) {
+        updatedFolders.unshift(newItem);
+        if (updatedFolders.length > 10) {
+          updatedFolders.pop(); // Remove the oldest entry if we exceed the 10 item limit
+        }
+      } else if (index > 0) {
+        // If the folder is already in the list, move it to the front
+        updatedFolders.splice(index, 1);
+        updatedFolders.unshift(newItem);
+      }
+      return updatedFolders;
+    }
+  };
+
   // useEffect that runs when the current folder in fileBrowserState changes,
   // to update the recently viewed folder
   React.useEffect(() => {
@@ -643,6 +669,10 @@ export const PreferencesProvider = ({
       return;
     }
 
+    if (loadingRecentlyViewedFolders) {
+      return;
+    }
+
     const fspName = fileBrowserState.currentFileSharePath.name;
     const folderPath = fileBrowserState.currentFileOrFolder.path;
 
@@ -668,7 +698,11 @@ export const PreferencesProvider = ({
       }
 
       try {
-        const updatedFolders = updateRecentlyViewedFolders(folderPath, fspName);
+        const updatedFolders = updateRecentlyViewedFolders(
+          folderPath,
+          fspName,
+          recentlyViewedFolders
+        );
         // Check again if cancelled before updating state
         if (isCancelled) {
           return;
@@ -677,7 +711,7 @@ export const PreferencesProvider = ({
         await savePreferencesToBackend('recentlyViewedFolders', updatedFolders);
       } catch (error) {
         if (!isCancelled) {
-          console.error('Error updating recently viewed folders:', error);
+          log.error('Error updating recently viewed folders:', error);
         }
       }
     };
@@ -688,8 +722,9 @@ export const PreferencesProvider = ({
     };
   }, [
     fileBrowserState, // Include the whole state object to satisfy ESLint
-    updateRecentlyViewedFolders,
-    savePreferencesToBackend
+    recentlyViewedFolders,
+    savePreferencesToBackend,
+    loadingRecentlyViewedFolders
   ]);
 
   return (
@@ -699,10 +734,14 @@ export const PreferencesProvider = ({
         handlePathPreferenceSubmit,
         hideDotFiles,
         toggleHideDotFiles,
+        areDataLinksAutomatic,
+        toggleAutomaticDataLinks,
         disableNeuroglancerStateGeneration,
         toggleDisableNeuroglancerStateGeneration,
         disableHeuristicalLayerTypeDetection,
         toggleDisableHeuristicalLayerTypeDetection,
+        useLegacyMultichannelApproach,
+        toggleUseLegacyMultichannelApproach,
         zonePreferenceMap,
         zoneFavorites,
         fileSharePathPreferenceMap,
@@ -714,9 +753,12 @@ export const PreferencesProvider = ({
         recentlyViewedFolders,
         layout,
         handleUpdateLayout,
+        setLayoutWithPropertiesOpen,
         loadingRecentlyViewedFolders,
         isLayoutLoadedFromDB,
-        handleContextMenuFavorite
+        handleContextMenuFavorite,
+        isFilteredByGroups,
+        toggleFilterByGroups
       }}
     >
       {children}
