@@ -195,7 +195,7 @@ function getLayerName(dataUrl: string): string {
   return dataUrl.split('/').filter(Boolean).pop() || 'Default';
 }
 
-function generateNeuroglancerStateForDataURL(dataUrl: string): string | null {
+function generateNeuroglancerStateForDataURL(dataUrl: string): string {
   log.debug('Generating Neuroglancer state for Zarr array:', dataUrl);
   const layer: Record<string, any> = {
     name: getLayerName(dataUrl),
@@ -223,7 +223,7 @@ function generateNeuroglancerStateForZarrArray(
   dataUrl: string,
   zarrVersion: 2 | 3,
   layerType: LayerType
-): string | null {
+): string {
   log.debug('Generating Neuroglancer state for Zarr array:', dataUrl);
 
   const layer: Record<string, any> = {
@@ -249,9 +249,58 @@ function generateNeuroglancerStateForZarrArray(
 }
 
 /**
- * Generate a Neuroglancer state for a given Zarr array.
+ * Generate a simple Neuroglancer state for a given Zarr array (non-legacy approach).
  */
-function generateNeuroglancerStateForOmeZarr(
+function generateSimpleNeuroglancerStateForOmeZarr(
+  dataUrl: string,
+  layerType: LayerType,
+  multiscale: omezarr.Multiscale,
+  arr: zarr.Array<any>
+): string {
+  log.debug('Generating simple Neuroglancer state for OME-Zarr:', dataUrl);
+
+  // Convert axes array to a map for easier access
+  const axesMap = getAxesMap(multiscale);
+
+  // Determine the layout based on the z-axis
+  let layout = '4panel-alt';
+  if ('z' in axesMap) {
+    const zAxisIndex = axesMap['z'].index;
+    const zDimension = arr.shape[zAxisIndex];
+    if (zDimension === 1) {
+      layout = 'xy';
+    }
+  }
+
+  // If the layer type is segmentation AND there is no channel axis or the channel axis has only one channel
+  const type =
+    layerType === 'segmentation' &&
+    (!axesMap['c'] || arr.shape[axesMap['c']?.index] === 1)
+      ? 'segmentation'
+      : 'auto';
+
+  const state = {
+    layout: layout,
+    layers: [
+      {
+        name: getLayerName(dataUrl),
+        source: 'zarr://' + dataUrl,
+        type
+      }
+    ]
+  };
+
+  log.debug('Simple Neuroglancer state: ', state);
+
+  // Convert the state to a URL-friendly format
+  const stateJson = JSON.stringify(state);
+  return encodeURIComponent(stateJson);
+}
+
+/**
+ * Generate a legacy Neuroglancer state for a given Zarr array (multichannel approach).
+ */
+function generateLegacyNeuroglancerStateForOmeZarr(
   dataUrl: string,
   zarrVersion: 2 | 3,
   layerType: LayerType,
@@ -351,7 +400,7 @@ function generateNeuroglancerStateForOmeZarr(
   }
 
   if (channels.length === 0) {
-    log.debug('No channels found in metadata, using default shader');
+    log.trace('No channels found in metadata, using default shader');
     const layer: Record<string, any> = {
       type: layerType,
       source: getNeuroglancerSource(dataUrl, zarrVersion),
@@ -432,29 +481,87 @@ function generateNeuroglancerStateForOmeZarr(
   return encodeURIComponent(stateJson);
 }
 
+/**
+ * Generate a Neuroglancer state for a given Zarr array.
+ */
+function generateNeuroglancerStateForOmeZarr(
+  dataUrl: string,
+  zarrVersion: 2 | 3,
+  layerType: LayerType,
+  multiscale: omezarr.Multiscale,
+  arr: zarr.Array<any>,
+  omero?: omezarr.Omero | null,
+  useLegacyMultichannelApproach: boolean = false
+): string | null {
+  // If using legacy multichannel approach, use the complex version
+  if (useLegacyMultichannelApproach) {
+    return generateLegacyNeuroglancerStateForOmeZarr(
+      dataUrl,
+      zarrVersion,
+      layerType,
+      multiscale,
+      arr,
+      omero
+    );
+  }
+
+  // Otherwise use the simpler version
+  return generateSimpleNeuroglancerStateForOmeZarr(
+    dataUrl,
+    layerType,
+    multiscale,
+    arr
+  );
+}
+
 async function getZarrArray(
   dataUrl: string,
-  zarrVersion: 2 | 3
+  zarrVersion: 2 | 3,
+  xrsfCookie: string
 ): Promise<zarr.Array<any>> {
-  log.debug('Getting Zarr array for', dataUrl);
-  const store = new zarr.FetchStore(dataUrl);
+  const store = new zarr.FetchStore(dataUrl, {
+    overrides: {
+      credentials: 'include',
+      headers: {
+        'X-Xsrftoken': xrsfCookie
+      }
+    }
+  });
   return await omezarr.getArray(store, '/', zarrVersion);
 }
 
 /**
  * Process the given OME-Zarr array and return the metadata, thumbnail, and Neuroglancer link.
  */
-async function getOmeZarrMetadata(dataUrl: string): Promise<Metadata> {
+async function getOmeZarrMetadata(
+  dataUrl: string,
+  xrsfCookie: string
+): Promise<Metadata> {
   log.debug('Getting OME-Zarr metadata for', dataUrl);
-  const store = new zarr.FetchStore(dataUrl);
+  const store = new zarr.FetchStore(dataUrl, {
+    overrides: {
+      credentials: 'include',
+      headers: {
+        'X-Xsrftoken': xrsfCookie
+      }
+    }
+  });
   const { arr, shapes, multiscale, omero, scales, zarr_version } =
     await omezarr.getMultiscaleWithArray(store, 0);
-  log.debug('Array: ', arr);
-  log.debug('Shapes: ', shapes);
-  log.debug('Multiscale: ', multiscale);
-  log.debug('Omero: ', omero);
-  log.debug('Scales: ', scales);
-  log.debug('Zarr version: ', zarr_version);
+  log.debug(
+    'Zarr version: ',
+    zarr_version,
+    '\nArray: ',
+    arr,
+    '\nShapes: ',
+    shapes,
+    '\nMultiscale: ',
+    multiscale,
+    '\nOmero: ',
+    omero,
+    '\nScales: ',
+    scales
+  );
 
   const metadata: Metadata = {
     arr,
@@ -472,12 +579,22 @@ type ThumbnailResult = [thumbnail: string | null, errorMessage: string | null];
 
 async function getOmeZarrThumbnail(
   dataUrl: string,
+  xrsfCookie: string,
+  signal: AbortSignal,
   thumbnailSize: number = 300,
   maxThumbnailSize: number = 1024,
   autoBoost: boolean = true
 ): Promise<ThumbnailResult> {
   log.debug('Getting OME-Zarr thumbnail for', dataUrl);
-  const store = new zarr.FetchStore(dataUrl);
+  const store = new zarr.FetchStore(dataUrl, {
+    overrides: {
+      credentials: 'include',
+      headers: {
+        'X-Xsrftoken': xrsfCookie
+      },
+      signal
+    }
+  });
   try {
     return [
       await omezarr.renderThumbnail(
@@ -500,141 +617,107 @@ async function getOmeZarrThumbnail(
 }
 
 /**
- * Fetches a chunk-aligned crop from a zarr array and analyzes all values
- * in the crop to compute the percentage of unique values. If the crop size
- * is smaller than the chunk size, only a single chunk is fetched.
- *
- * @param metadata - The metadata object containing the zarr array
- * @param cropSize - The size of the crop to take (default: 64)
- * @returns Promise<number> - The percentage of unique values in the cropped data
+ * Analyzes edge content in a thumbnail by shifting it 1 pixel to the right,
+ * subtracting from the original, and calculating the ratio of non-zero pixels.
+ * @param thumbnailDataUrl - Base64 data URL of the thumbnail image
+ * @returns Promise<number> - The ratio of edge pixels to total pixels
  */
-async function getPercentUniqueValues(
-  metadata: Metadata,
-  cropSize: number = 32
+async function analyzeThumbnailEdgeContent(
+  thumbnailDataUrl: string
 ): Promise<number> {
-  try {
-    const arr = metadata.arr;
-    const arrayShape = arr.shape;
-    const chunks = arr.chunks;
-    log.trace('Array shape:', arrayShape);
-    log.trace('Chunk sizes:', chunks);
+  return new Promise((resolve, reject) => {
+    const img = new Image();
+    img.onload = () => {
+      try {
+        const canvas = document.createElement('canvas');
+        const ctx = canvas.getContext('2d');
+        if (!ctx) {
+          reject(new Error('Could not get canvas context'));
+          return;
+        }
 
-    // Calculate the center point of the array
-    const centerPoint = arrayShape.map(dimSize => Math.floor(dimSize / 2));
-    log.trace('Center point:', centerPoint);
+        // Get original image data
+        canvas.width = img.width;
+        canvas.height = img.height;
+        ctx.drawImage(img, 0, 0);
+        const origData = ctx.getImageData(0, 0, img.width, img.height);
 
-    // Align crop to chunk boundaries
-    const startIndices: number[] = [];
-    const endIndices: number[] = [];
+        // Clear canvas and draw shifted image (1 pixel to the right)
+        ctx.clearRect(0, 0, canvas.width, canvas.height);
+        ctx.drawImage(img, 1, 0);
+        const shiftData = ctx.getImageData(0, 0, img.width, img.height);
 
-    for (let i = 0; i < arrayShape.length; i++) {
-      const chunkSize = chunks[i];
-      log.trace('Chunk size:', chunkSize);
-      const center = centerPoint[i];
-      log.trace('Center:', center);
+        let nonZeroPixels = 0;
+        const totalPixels = img.width * img.height;
 
-      // Find which chunk contains the center point
-      const centerChunkIndex = Math.floor(center / chunkSize);
-      log.trace('Center chunk index:', centerChunkIndex);
+        // Compare original and shifted images pixel by pixel
+        for (let i = 0; i < origData.data.length; i += 4) {
+          // Calculate difference for RGB channels (ignore alpha)
+          const rDiff = Math.abs(origData.data[i] - shiftData.data[i]);
+          const gDiff = Math.abs(origData.data[i + 1] - shiftData.data[i + 1]);
+          const bDiff = Math.abs(origData.data[i + 2] - shiftData.data[i + 2]);
 
-      // Calculate the start and end indices
-      startIndices[i] = centerChunkIndex * chunkSize;
-      log.trace('Start index:', startIndices[i]);
-      endIndices[i] = Math.min(startIndices[i] + cropSize, arrayShape[i]);
-      log.trace('End index:', endIndices[i]);
-    }
+          // If any channel has a significant difference, count as edge pixel
+          if (rDiff > 0 || gDiff > 0 || bDiff > 0) {
+            nonZeroPixels++;
+          }
+        }
 
-    // Create selection slice for the crop
-    const selection = startIndices.map((start, i) => [start, endIndices[i]]);
+        const edgeRatio = nonZeroPixels / totalPixels;
 
-    log.debug(
-      'Crop dimensions:',
-      selection.map(([start, end]) => end - start)
-    );
-
-    // Fetch the crop data using zarrita's get API
-    const cropSelection = selection.map(([start, end]) =>
-      zarr.slice(start, end)
-    );
-    const cropData = await zarr.get(arr, cropSelection);
-
-    // Convert to typed array for easier processing
-    let flatData: ArrayLike<number>;
-    if (
-      cropData.data instanceof ArrayBuffer ||
-      ArrayBuffer.isView(cropData.data)
-    ) {
-      flatData = new Float32Array(cropData.data as ArrayBuffer);
-    } else if (Array.isArray(cropData.data)) {
-      flatData = cropData.data as number[];
-    } else {
-      // Handle TypedArray case
-      flatData = cropData.data as ArrayLike<number>;
-    }
-    const totalValues = flatData.length;
-
-    log.debug('Total values in chunk-aligned crop:', totalValues);
-
-    // Analyze all values in the crop
-    const uniqueValues = new Set<number>();
-    for (let i = 0; i < totalValues; i++) {
-      const value = flatData[i];
-      if (!isNaN(value)) {
-        uniqueValues.add(value);
+        log.debug(
+          `Edge detection analysis: found ${nonZeroPixels} edge pixels out of ${totalPixels} total pixels`
+        );
+        resolve(edgeRatio);
+      } catch (error) {
+        reject(error);
       }
-    }
+    };
 
-    const uniqueCount = uniqueValues.size;
-    log.debug(
-      `Analyzed ${totalValues} values, found ${uniqueCount} unique values`
-    );
+    img.onerror = () => {
+      reject(new Error('Failed to load thumbnail image'));
+    };
 
-    return uniqueCount / totalValues;
-  } catch (error) {
-    log.error(
-      'Error fetching chunk-aligned crop for unique value analysis:',
-      error
-    );
-    throw error;
-  }
+    img.src = thumbnailDataUrl;
+  });
 }
 
 /**
- * Determines the layer type for the given metadata.
+ * Determines the layer type for the given OME-Zarr metadata.
  * If heuristical detection is disabled, returns "image".
- * If the image has multiple timepoints or multiple channels,
- * returns "image" without counting unique values.
+ * Uses thumbnail edge detection to determine if data is segmentation or image.
  *
- * Otherwise, analyzes unique values to determine if it's a segmentation or image.
- *
- * @param metadata - The metadata object containing the zarr array and multiscale info
- * @param useHeuristicalDetection - If true, skip heuristical detection and return "auto"
+ * @param useHeuristicalDetection - If true, skip heuristical detection and return "image"
+ * @param thumbnailDataUrl - Optional thumbnail data URL for edge content analysis
  * @returns Promise<LayerType> - The determined layer type
  */
-async function getLayerType(
-  metadata: Metadata,
-  useHeuristicalDetection = true
+async function determineLayerType(
+  useHeuristicalDetection = true,
+  thumbnailDataUrl?: string | null
 ): Promise<LayerType> {
+  const DEFAULT_LAYER_TYPE = 'image';
   try {
-    // If heuristical detection is disabled, return "auto"
     if (!useHeuristicalDetection) {
-      log.debug('Heuristical layer type detection is disabled, assuming image');
-      return 'image';
+      log.debug('Heuristical layer type detection is disabled');
+    } else if (thumbnailDataUrl) {
+      try {
+        const edgeRatio = await analyzeThumbnailEdgeContent(thumbnailDataUrl);
+        log.debug('Thumbnail edge detection ratio:', edgeRatio);
+        // Segmentation data typically has low edge ratio
+        const layerType =
+          edgeRatio > 0.0 && edgeRatio < 0.05 ? 'segmentation' : 'image';
+        log.debug(`Layer type set to ${layerType} based on edge analysis`);
+        return layerType;
+      } catch (error) {
+        log.error('Failed to analyze thumbnail edge content:', error);
+      }
+    } else {
+      log.debug('No thumbnail available, returning image');
     }
-
-    // If no multiple timepoints or channels, analyze unique values
-    const uniqueValuePercent = await getPercentUniqueValues(metadata);
-    log.debug('Percentage unique values:', uniqueValuePercent);
-
-    const layerType = uniqueValuePercent < 0.001 ? 'segmentation' : 'image';
-    log.debug('Determined layer type based on unique values:', layerType);
-
-    return layerType;
   } catch (error) {
     log.error('Error determining layer type:', error);
-    // Default to 'image' if we can't determine the type
-    return 'image';
   }
+  return DEFAULT_LAYER_TYPE;
 }
 
 export {
@@ -647,5 +730,6 @@ export {
   generateNeuroglancerStateForZarrArray,
   generateNeuroglancerStateForOmeZarr,
   translateUnitToNeuroglancer,
-  getLayerType
+  determineLayerType,
+  analyzeThumbnailEdgeContent
 };
