@@ -6,9 +6,16 @@ function createSuccess<T>(data: T): Success<T> {
 }
 
 async function toHttpError(response: Response): Promise<Error> {
-  const body = await response.json();
+  let body = { error: null };
+  try {
+    if (!response.bodyUsed) {
+      body = await response.json();
+    }
+  } catch (error) {
+    logger.error('Error parsing JSON response:', error);
+  }
   return new Error(
-    `${response.status}: ${body.error ? body.error : 'Unknown error'}`
+    body.error ? body.error : `Unknown error (${response.status})`
   );
 }
 
@@ -32,4 +39,4 @@ function handleError(error: unknown): Failure {
   return createFailure(errorString);
 }
 
-export { createSuccess, handleError, toHttpError };
+export { createSuccess, handleError, toHttpError, getErrorString };
